
# Type: produces


holds between a material entity and a product that is generated through the intentional actions or functioning of the material entity

URI: [biolink:produces](https://w3id.org/biolink/vocab/produces)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0003000 |
|  | | WD:P1056 |
|  | | SEMMEDDB:PRODUCES |
| **In Subsets:** | | translator_minimal |

